CVR plugin for Quantiphyse
==========================

This plugin provides modelling tools for cerebrovascular reactivity
(CVR) using BOLD-MRI with PETCO2

Quantiphyse and quantiphyse-fabber must be installed. To
install the plugin from PyPi use:

    pip install quantiphyse-cvr

The plugin will then be available from within Quantiphyse

